import axios from 'axios'
import { message } from 'antd'

const prefix = '/api2/api/v1'

export const request2 = axios.create({
  baseURL: `${prefix}`,
  timeout: 50000
})

request2.interceptors.request.use(config => {
  if (sessionStorage.getItem('area-garden-token')) {
    config.headers['token'] = sessionStorage.getItem('area-garden-token')
  }
  
  if (config?.params?.current) {
    config.params.page = config.params.current
    delete config.params.current
  }
  
  if (config?.params?.pageSize){
    config.params.page_size=config.params.pageSize 
    delete config.params.pageSize
  }
  
  if (config?.data?.method) {
    delete config.data.method
  }
  return config
})

const errorHandler = code => {
  // login
  if ([10008, 10009].includes(code)) {
    window.location.href = '/#/login'
  }
  if ([10004].includes(code)) {}
}

request2.interceptors.response.use(response => {
  let res = response.data
  if (!res.code) {
    if (res.data?.list) {
      return {
        success: true,
        data: res.data.list,
        total: res.data.total,
        ...res.data
      }
    }
  }

  if (res.code) {
    const error = res.message
    message.error(error)
    errorHandler(res.code)
    throw error
  }
  return res
},error=>{
  if (error && error.response && error.response.status!=200){
    message.error("服务器异常")
	throw "服务器异常"
  }
})

export default request2
