import { Button, Modal, Form, Input, InputNumber, message } from "antd";
import React, { useEffect, useState } from "react";
import type { ActionType } from "@ant-design/pro-table";
import ProTable from "@ant-design/pro-table";
import { PlusOutlined } from "@ant-design/icons";
import { Company_user } from "../../services/account";
import { getLocalTime } from "../../utils/utils";
import sha256 from 'sha256'

const Account = () => {
    const columns: any = [
        {
            title: "用户名",
            align: "center",
            dataIndex: "user_name"
        },
        {
            title: "邮箱",
            align: "center",
            dataIndex: "email"
        },
        {
            title: "联系电话",
            align: "center",
            dataIndex: "phone"
        },
        {
            title: "创建时间",
            align: "center",
            dataIndex: "created_at",
            render: (_, row) => getLocalTime(row.created_at)
        },
        {
            title: "操作",
            align: "center",
            dataIndex: "option",
            render: (_, row) => <>
                <Button type="link" onClick={() => {
                    controlModal(true)
                    setState(pre => ({ ...pre, id: row.id }));
                    form.setFieldsValue(row)
                }}>修改</Button>
                <Button type="link" onClick={() => deleteUser(row.id)}>删除</Button>
            </>
        },
    ]
    const actionRef: any = React.useRef<ActionType>();
    const [form] = Form.useForm();
    const [state, setState] = useState({
        visible: false,
        id: null,
    });
    const controlModal = (flag) => {
        setState({ id: null, visible: flag })
    }
    const onSubmit = () => {
        form.validateFields().then(async (values) => {
            console.log(values);
            let { password } = values;
            await Company_user({
                ...values,
                password: sha256(password),
                method: state.id ? "put" : 'post',
                id: state.id ? state.id : null,
            })
            message.success("操作成功");
            controlModal(false);
            actionRef.current?.reload();
        })
    }
    const deleteUser = (id) => {
        Modal.confirm({
            title: "删除记录",
            content: "你确定删除这条记录吗？",
            onOk: async () => {
                await Company_user({ method: "delete", id });
                message.success("操作成功！");
                actionRef.current.reload();
            }
        });
    }
    return (<>
        <ProTable
            actionRef={actionRef}
            rowKey="id"
            request={Company_user}
            search={false}
            options={false}
            toolBarRender={() => [
                <><Button
                    type="primary"
                    key="primary"
                    icon={<PlusOutlined />}
                    onClick={() => {
                        controlModal(true);
                        form.resetFields()
                    }}
                >
                    添加
                </Button></>
            ]}
            columns={columns}
        />
        <Modal
            title={state.id ? "修改用户" : "添加用户"}
            visible={state.visible}
            width={400}
            onOk={onSubmit}
            maskClosable={false}
            onCancel={() => controlModal(false)}
        >
            <Form labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} form={form}>
                <Form.Item label="用户名" name="user_name" rules={[{ required: true, message: "请输入用户名" }]}  >
                    <Input placeholder="请输入用户名" />
                </Form.Item>
                <Form.Item label="密码" name="password" rules={[
                    {
                        required: true,
                        message: '请输入密码！',
                    },
                    {
                        pattern: /^(?=.*\d)(?=.*[a-zA-Z])(?=.*[\W_]).{8,}$/,
                        message: '密码必须包括数字、字母、特殊字符',
                    },
                ]} >
                    <Input.Password placeholder="请输入密码" />
                </Form.Item>
                <Form.Item label="姓名" name="real_name" rules={[{ required: true, message: "请输入姓名" }]}  >
                    <Input placeholder="请输入姓名" />
                </Form.Item>
                <Form.Item name="phone" label="手机号" rules={[
                    {
                        required: true,
                        message: '请输入手机号！',
                    },
                    {
                        pattern: /^((1[3,5,8,7,9][0-9])|(14[5,7])|(17[0,6,7,8])|(19[7]))\d{8}$/,
                        message: '手机号格式错误！',
                    },
                ]}>
                    <Input placeholder="请输入手机号" />
                </Form.Item>
                <Form.Item label="邮箱" name="email" rules={[
                    {
                        required: false,
                        message: '请输入邮箱',
                    },
                    {
                        pattern: /^[A-Za-z0-9\u4e00-\u9fa5]+@[a-zA-Z0-9_-]+(\.[a-zA-Z0-9_-]+)+$/,
                        message: '邮箱格式错误！',
                    },
                ]}>
                    <Input placeholder="请输入邮箱" />
                </Form.Item>
            </Form>
        </Modal>
    </>)
}

export default Account