import * as React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Select, Popconfirm, message } from 'antd'
import { PlusOutlined } from '@ant-design/icons'
import { Link, withRouter } from 'react-router-dom'
import { Garden, GanderEntry, Company_login ,GardenCheck} from '../../services/garden'

const GardenList= (props: any) => {
  const columns: any = [
    {
      title: '小区名称',
      dataIndex: 'garden_name'
    },
    {
      title: '城市',
      dataIndex: 'city',
      search: false
    },
    {
      title: '街道社区',
      dataIndex: 'committee',
      search: false
    },
    {
      title: '小区详细地址',
      dataIndex: 'garden_addr',
      search: false,
    },
    {
      title: '物业联系人',
      dataIndex: 'property_person',
      search: false,
    },
    {
      title: '物业联系电话',
      dataIndex: 'property_phone',
      search: false,
    },
    {
        title:"审核状态",
        dataIndex:"status",
        search:false,
        valueEnum:{
            1:{text:"待审批",status:"Default"},
            2:{text:"通过",status:"Success"},
            3:{text:"审核未通过",status:"Error"}
        }
    }
   
  ]
  const [state, setState] = React.useState({
    visible: false,
    examineVisible: false,
    id: null
  })
  const actionRef = React.useRef<ActionType>();
  const deleteGarden = async (id) => {
    console.log(id);

    await Garden({ method: 'delete', id })
    message.success('删除成功')
    actionRef.current?.reload()
  }

  const manageLogin = async (id) => {
    const { data } = await GanderEntry({ garden_id: id })
    sessionStorage.setItem('area-garden-token', data.token)
    Company_login({ token: data.token }).then(res => {
      let win = window.open('http://47.108.135.38:30002/admin/index')
      window.addEventListener('message', (e) => {
        win?.postMessage({ token: res.data.token }, '*')
      })
    })
  }
  const addGarden = () =>{
    GardenCheck().then(res=>{
      console.log(res);
      if(res.data.can_add==true){
        props.history.push('/admin/garden/create')
      }else{
        message.error("小区数量用尽，暂时无法添加")
      }
    }) 
  }
  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey={row => row.id}
        options={false}
        request={Garden}
        columns={columns}
        params={{not_approved:true}}
        toolBarRender={() => [
          <Button type='primary' onClick={addGarden}>  <PlusOutlined />添加</Button>
        ]}
      />
    </React.Fragment>
  )
}

export default withRouter(GardenList)