import React, { FC, useEffect, useState } from 'react'
import './index.scss'
import { GetProvinceCityArea } from '../../services/api'
import { GetGardenStreet } from '../../services/garden'
import { Package_for_garden } from '../../services/buypackage';
import { Garden } from '../../services/garden';
import { Form, Card, DatePicker, Select, Input, Button, Upload, message, Modal, InputNumber, Cascader } from 'antd'
import { UploadOutlined } from '@ant-design/icons'
import { goBack } from '../../utils/hisitory';
import Address from './demo';
import moment from 'moment'
import { GetTimeStamp } from '../../utils/utils';

const { RangePicker } = DatePicker;
const buildingTypes = [
  { label: "塔楼", value: 1 },
  { label: "板楼", value: 2 },
  { label: "塔板结合", value: 3 },
  { label: "其他", value: 4 }
]
const GardenCreate: FC = (props) => {
  const [previewVisible, setPreviewVisible] = useState(false);
  const [previewImage, setPreviewImage] = useState();
  const [previewTitle, setPreviewTitle] = useState('');
  const [packageItem, setpackageItem]: any = useState([])
  const handleCancel = () => setPreviewVisible(false);
  const [form] = Form.useForm()
  const createGarden = () => {
    form.validateFields().then(async (value) => {
      const { avg_price, property_fee_start, property_fee_end, garden_pics,
        lntlat: { lnt, lat }, appendix, garden_pic,
        building_year, gas_fee_start, gas_fee_end, water_type, electric_type,
        provice_city, street_committee
      } = value;
      let province, province_code, city, city_code, area, area_code,
        street, street_code, committee, committee_code
      provice_city.map((item, index) => {
        if (index == 0) {
          let val = item.split(',');
          province = val[0];
          province_code = val[1]
        } else if (index == 1) {
          let val = item.split(',');
          city = val[0];
          city_code = val[1]
        } else if (index == 2) {
          let val = item.split(',');
          area = val[0];
          area_code = val[1]
        }
      })
      street_committee.map((item, index) => {
        if (index == 0) {
          let val = item.split(',');
          street = val[0];
          street_code = val[1]
        } else if (index == 1) {
          let val = item.split(',');
          committee = val[0];
          committee_code = val[1]
        }
      })
      await Garden({
        method: 'post',
        ...value,
        // ...newGarden,
        province, province_code, city, city_code, area, area_code,
        street, street_code, committee, committee_code,
        lnt,
        lat,
        garden_pic: garden_pic[0].response.data,
        appendix: appendix.map(item => item.response.data),
        avg_price: avg_price ? avg_price * 100 : 0,
        property_fee_start: property_fee_start ? property_fee_start * 100 : 0,
        property_fee_end: property_fee_end ? property_fee_end * 100 : 0,
        gas_fee_start: gas_fee_start ? gas_fee_start * 100 : 0,
        gas_fee_end: gas_fee_end ? gas_fee_end * 100 : 0,
        garden_pics: garden_pics ? garden_pics.map(item => item.response.data) : [],
        building_start: building_year ? GetTimeStamp(moment(building_year[0]).format("YYYY")) : 0,
        building_end: building_year ? GetTimeStamp(moment(building_year[1]).format("YYYY")) : 0,
        water_type: water_type ? water_type.map(item => parseInt(item)) : [],
        electric_type: electric_type ? electric_type.map(item => parseInt(item)) : []
      })
      message.success('添加成功,请等待审核')
      goBack()
    }).catch(err => {
      let errorFields = err.errorFields;
      form.scrollToField(errorFields[0].name)
    })
  }

  useEffect(() => {
    Package_for_garden().then(res => {
      let data = res.data.map(item => {
        return { label: item.name, value: item.order_id }
      })
      setpackageItem(data);
    })
  }, [])
  const onChange = async (value) => {
    form.resetFields(["street_committee"])
    const area_code = value[value.length - 1].split(',');
    let { Data } = await GetGardenStreet({ area_code: area_code[area_code.length - 1] });
    const { street_list, committee_list } = Data;
    let list = street_list.map(item => {
      let committee: any = [];
      committee_list.map(key => {
        if (item.code == key.street_code) {
          committee.push({ ...key, code: `${key.name},${key.code}` })
        }
      })
      return { ...item, code: `${item.name},${item.code}`, children: committee }
    })
    setStreetOptions(list);
  };
  const [options, setOptions] = useState([]);
  const [streetOptions, setStreetOptions] = useState([]);
  useEffect(() => {
    getOptions();
  }, [])
  const getOptions = async () => {
    const { data } = await GetProvinceCityArea({});
    const { province_list, city_list, area_list } = data;
    let list = province_list.map(item => {
      let city: any = [];
      city_list.map(key => {
        let area: any = [];
        if (item.code == key.province_code) {
          area_list.map(val => {
            if (key.code == val.city_code) {
              area.push({ ...val, code: `${val.name},${val.code}` })
            }
          })
          city.push({ ...key, code: `${key.name},${key.code}`, children: area })
        }
      })
      return { ...item, code: `${item.name},${item.code}`, children: city }
    })
    setOptions(list)
  }
  const gardenInfoForm = [
    { label: "小区名字", name: "garden_name" },
    { label: "物业联系人", name: "property_person" },
    { label: "物业联系人手机号", name: "property_phone" }
  ]
  const gardenInfo = [
    { label: "开发商", name: "building_company" },
    { label: "总户数", name: "house_total" },
    { label: "固定车位数", name: "space_total" },
    { label: "车位配比", name: "space_info" },
    { label: "容积率", name: "area_percent" },
    { label: "绿化率", name: "green_percent" },
    { label: "小区占地面积", name: "covered_area" },
    { label: "小区建筑面积", name: "building_area" },
  ]
  const uploadProps: any = {
    name: "file",
    action: "/api1/api/v1/upload",
    headers: {
      token: sessionStorage.getItem('area-token')
    },
    listType: "picture",
    maxCount: 1,
  }
  const normFile = (e: any) => {
    if (Array.isArray(e)) {
      return e;
    }
    return e && e.fileList;
  };
  const getValue = (val) => {
    const { addr, longitude, latitude } = val;
    form.setFieldsValue({ garden_addr: addr, lntlat: { lnt: longitude, lat: latitude } })
  }
  const getBase64 = (file) =>
    new Promise((resolve, reject) => {
      const reader = new FileReader();
      reader.readAsDataURL(file);

      reader.onload = () => resolve(reader.result);

      reader.onerror = (error) => reject(error);
    });
  const handlePreview = async (file) => {
    if (!file.url && !file.preview) {
      file.preview = await getBase64(file.originFileObj);
    }

    setPreviewImage(file.url || file.preview);
    setPreviewVisible(true);
    setPreviewTitle(file.name || file.url.substring(file.url.lastIndexOf('/') + 1));
  };
  return (
    <><Card
      extra={<Button type='primary' onClick={goBack}>返回</Button>}
    >
      <div className={'form-block__title'}>基本信息</div>
      <Form form={form}
        labelAlign='left'
        labelCol={{ span: 4 }}
        wrapperCol={{ span: 8, offset: 1 }}
      >
        <Form.Item label="城市" name="provice_city" rules={[{ required: true, message: "请选择小区区域" }]}>
          <Cascader options={options} onChange={onChange} placeholder="请选择小区区域"
            fieldNames={{
              label: "name",
              value: "code"
            }}
          />
        </Form.Item>
        <Form.Item label="社区" name="street_committee" rules={[{ required: true, message: "请选择社区" }]}>
          <Cascader options={streetOptions} placeholder="请选择社区"
            fieldNames={{
              label: "name",
              value: "code"
            }}
          />
        </Form.Item>
        {gardenInfoForm.map(item => {
          return (
            <Form.Item
              label={item.label}
              name={item.name}
              key={item.name}
              rules={[{ required: true, message: `请输入${item.label}` }]}
            >
              <Input placeholder={`请输入${item.label}`}></Input>
            </Form.Item>);
        })}
        <Form.Item label="套餐" name="order_id" rules={[{ required: true, message: "请选择套餐" }]}>
          <Select placeholder='请选择套餐' options={packageItem} />
        </Form.Item>
        <Form.Item label='小区描述' name='garden_desc' rules={[{ required: true, message: "请输入小区描述" }]}>
          <Input.TextArea placeholder='请输入小区描述'></Input.TextArea>
        </Form.Item>
        <Form.Item label='小区形象图片' name='garden_pic' rules={[{ required: true, message: "请上传小区形象图片" }]}
          valuePropName="fileList"
          getValueFromEvent={normFile}
        >
          <Upload {...uploadProps}
            onPreview={handlePreview}
          >
            <Button icon={<UploadOutlined />}>上传小区形象图片</Button>
          </Upload>
        </Form.Item>
        <Form.Item label='证明材料' name='appendix' rules={[{ required: true, message: "请上传证明材料" }]}
          valuePropName="fileList"
          getValueFromEvent={normFile}
        >
          <Upload {...uploadProps}
            maxCount={3}
            onPreview={handlePreview}
          >
            <Button icon={<UploadOutlined />}>上传证明材料</Button>
          </Upload>
        </Form.Item>
        <Form.Item label='请选择小区位置' name='lntlat' rules={[{ required: true, message: "请选择对应小区位置" }]}>
          <Address  getValue={getValue} />
        </Form.Item>
        <Form.Item label="小区位置" name="garden_addr"
          wrapperCol={{ span: 12, offset: 1 }}
          rules={[{ required: true, message: "请输入小区位置" }]}
        >
          <Input placeholder='请输入小区详细位置' />
        </Form.Item>
        <div className={'form-block__title'}>小区信息（非必填）</div>
        <Form.Item label="建成年份" name="building_year">
          <RangePicker picker="year" allowEmpty={[true, true]} />
        </Form.Item>
        <Form.Item label="物业费用" style={{ marginBottom: 0 }} >
          <Form.Item
            name="property_fee_start"
            style={{ display: 'inline-block', width: "calc(40%)" }}
            dependencies={['property_fee_end']}
            rules={[
              ({ getFieldValue }) => ({
                validator(_, value) {
                  if (getFieldValue('property_fee_end')) {
                    if (!value) {
                      return Promise.reject(new Error('请输入最低价'));
                    }
                  }
                  return Promise.resolve();
                },
              }),
            ]}
          >
            <InputNumber min={0} prefix="￥" style={{ width: '100%' }} placeholder="最低价" />
          </Form.Item>
          <Form.Item style={{ display: 'inline-block', margin: '0 8px' }}>至</Form.Item>
          <Form.Item
            name="property_fee_end"
            dependencies={['property_fee_start']}
            rules={[
              ({ getFieldValue }) => ({
                validator(_, value) {
                  if (getFieldValue('property_fee_start')) {
                    if (!value) {
                      return Promise.reject(new Error('请输入最高价'));
                    } else if (getFieldValue('property_fee_start') > value) {
                      return Promise.reject(new Error('请输入合理的价格'));
                    }
                  }
                  return Promise.resolve();
                },
              }),
            ]}
            style={{ display: 'inline-block', width: "calc(40%)", margin: '0 8px' }}
          >
            <InputNumber min={0} prefix="￥" style={{ width: '100%' }} placeholder="最高价" />
          </Form.Item>
        </Form.Item>
        <Form.Item label="燃气费用" style={{ marginBottom: 0 }} >
          <Form.Item
            name="gas_fee_start"
            style={{ display: 'inline-block', width: "calc(40%)" }}
            dependencies={['gas_fee_end']}
            rules={[
              ({ getFieldValue }) => ({
                validator(_, value) {
                  if (getFieldValue('gas_fee_end')) {
                    if (!value) {
                      return Promise.reject(new Error('请输入最低价'));
                    }
                  }
                  return Promise.resolve();
                },
              }),
            ]}
          >
            <InputNumber min={0} prefix="￥" style={{ width: '100%' }} placeholder="最低价" />
          </Form.Item>
          <Form.Item style={{ display: 'inline-block', margin: '0 8px' }}>至</Form.Item>
          <Form.Item
            name="gas_fee_end"
            dependencies={['gas_fee_start']}
            rules={[
              ({ getFieldValue }) => ({
                validator(_, value) {
                  if (getFieldValue('gas_fee_start')) {
                    if (!value) {
                      return Promise.reject(new Error('请输入最高价'));
                    } else if (getFieldValue('gas_fee_start') > value) {
                      return Promise.reject(new Error('请输入合理的价格'));
                    }
                  }
                  return Promise.resolve();
                },
              }),
            ]}
            style={{ display: 'inline-block', width: "calc(40%)", margin: '0 8px' }}
          >
            <InputNumber min={0} prefix="￥" style={{ width: '100%' }} placeholder="最高价" />
          </Form.Item>
        </Form.Item>
        <Form.Item label="建筑类型" name="building_type">
          <Select placeholder='请选择建筑类型' allowClear options={buildingTypes} />
        </Form.Item>
        <Form.Item label="用水类型" name="water_type">
          <Select placeholder='请选择用水类型' allowClear mode="tags" options={[
            { label: "民用", value: '1' },
            { label: "商用", value: '2' },
          ]} />
        </Form.Item>
        <Form.Item label="用电类型" name="electric_type">
          <Select placeholder='请选择用电类型' allowClear mode="tags" options={[
            { label: "民用", value: '1' },
            { label: "商用", value: '2' },
          ]} />
        </Form.Item>
        <Form.Item label="小区均价" name="avg_price">
          <InputNumber min={0} prefix="￥" style={{ width: '100%' }} placeholder="请输入均价" />
        </Form.Item>
        {gardenInfo.map(item => {
          if (item.name == "area_percent" || item.name == "green_percent") {
            return (
              <Form.Item
                label={item.label}
                name={item.name}
                key={item.name}
              >
                <InputNumber placeholder={`请输入${item.label}`} addonAfter="%" />
              </Form.Item>);
          } else if (item.name == "building_area" || item.name == "covered_area") {
            return (
              <Form.Item
                label={item.label}
                name={item.name}
                key={item.name}
              >
                <InputNumber placeholder={`请输入${item.label}`} addonAfter="m²" />
              </Form.Item>);
          } else if (item.name == "space_total" || item.name == "house_total") {
            return (
              <Form.Item
                label={item.label}
                name={item.name}
                key={item.name}
              >
                <InputNumber placeholder={`请输入${item.label}`} style={{ width: "100%" }} />
              </Form.Item>);
          } else if (item.name == "space_info") {
            return (
              <Form.Item
                label={item.label}
                name={item.name}
                key={item.name}
                extra={<span>例：1:1.12 </span>}
              >
                <Input placeholder={`请输入${item.label}`} style={{ width: "100%" }} />
              </Form.Item>);
          }
          else {
            return (
              <Form.Item
                label={item.label}
                name={item.name}
                key={item.name}

              >
                <Input placeholder={`请输入${item.label}`} style={{ width: "100%" }} />
              </Form.Item>);
          }
        })}
        <Form.Item label='小区图片' name='garden_pics'
          valuePropName="fileList"
          getValueFromEvent={normFile}
        >
          <Upload {...uploadProps}
            onPreview={handlePreview}
            maxCount={6}
          >
            <Button icon={<UploadOutlined />}>上传小区图片</Button>
          </Upload>
        </Form.Item>
      </Form>
      <div className='createGardenBut'>
        <Button type='primary' onClick={createGarden}>创建</Button>
      </div>
    </Card><Modal visible={previewVisible} title={previewTitle} footer={null} onCancel={handleCancel}>
        <img
          alt="example"
          style={{
            width: '100%',
          }}
          src={previewImage} />
      </Modal></>
  )
}

export default GardenCreate