import {
    Button, Card, Form, Input, Image, Upload, message, DatePicker, InputNumber,
    Select,
} from "antd";
import React, { useEffect, useState } from "react";
import { useHistory } from "react-router"
import Uploadpic from "../../utils/upload";
import MapElement from "./myMap";
import Address from "./demo";
import { Garden } from "../../services/garden";
import { GetTimeStamp } from "../../utils/utils";
import moment from 'moment'
import './index.scss'

const { RangePicker } = DatePicker;
const buildingTypes = [
    { label: "塔楼", value: 1 },
    { label: "板楼", value: 2 },
    { label: "塔板结合", value: 3 },
    { label: "其他", value: 4 }
]
const gardenInfo = [
    { label: "开发商", name: "building_company" },
    { label: "总户数", name: "house_total" },
    { label: "固定车位数", name: "space_total" },
    { label: "车位配比", name: "space_info" },
    { label: "容积率", name: "area_percent" },
    { label: "绿化率", name: "green_percent" },
    { label: "小区占地面积", name: "covered_area" },
    { label: "小区建筑面积", name: "building_area" },
]
const EditGarden = (props) => {
    const history = useHistory()
    const location = history.location
    const state: any = location.state
    const [form] = Form.useForm();
    const [previewVisible, setPreviewVisible] = useState(false);
    const [previewImage, setPreviewImage] = useState();
    const [previewTitle, setPreviewTitle] = useState('');
    const [pic, setPic]: any = React.useState([]);
    const [pics, setPics]: any = React.useState([])
    const editInfoForm = [
        { label: "物业联系人", name: "property_person" },
        { label: "物业联系人手机号", name: "property_phone" }
    ]

    useEffect(() => {
        const { lnt, lat, garden_pics, garden_pic, avg_price, property_fee_start, property_fee_end,
            building_start, building_end, gas_fee_start, gas_fee_end, water_type, electric_type
        } = state;
        form.setFieldsValue(state)
        form.setFieldsValue({ lntlat: { lnt, lat } })
        form.setFieldsValue({ building_year: [moment(building_start * 1000), moment(building_end * 1000)] })
        form.setFieldsValue({ avg_price: avg_price / 100 });
        form.setFieldsValue({ property_fee_start: property_fee_start / 100 });
        form.setFieldsValue({ property_fee_end: property_fee_end / 100 });
        form.setFieldsValue({ gas_fee_start: gas_fee_start / 100 });
        form.setFieldsValue({ gas_fee_end: gas_fee_end / 100 });
        form.setFieldsValue({ water_type: water_type ? water_type.map(item => item + '') : [] });
        form.setFieldsValue({ electric_type: electric_type ? electric_type.map(item => item + '') : [] });
        setPic([garden_pic])
        if (garden_pics && garden_pics[0] !== '') {
            setPics(garden_pics)
        }
    }, [])
    const editGarden = () => {
        form.validateFields().then(async (value) => {
            const { id } = state
            const { avg_price, property_fee_start, property_fee_end,
                lntlat: { lnt, lat },
                building_year, gas_fee_start, gas_fee_end, water_type, electric_type
            } = value;
            await Garden({
                method: 'put',
                ...value,
                id,
                lnt,
                lat,
                avg_price: avg_price ? avg_price * 100 : 0,
                property_fee_start: property_fee_start ? property_fee_start * 100 : 0,
                property_fee_end: property_fee_end ? property_fee_end * 100 : 0,
                building_start: building_year ? GetTimeStamp(moment(building_year[0]).format("YYYY")) : 0,
                building_end: building_year ? GetTimeStamp(moment(building_year[1]).format("YYYY")) : 0,
                gas_fee_start: gas_fee_start ? gas_fee_start * 100 : 0,
                gas_fee_end: gas_fee_end ? gas_fee_end * 100 : 0,
                water_type: water_type ? water_type.map(item => parseInt(item)) : [],
                electric_type: electric_type ? electric_type.map(item => parseInt(item)) : []
            })
            message.success('修改成功')
            history.goBack()
        })
    }
    const getPicVal = (arr) => {
        form.setFieldsValue({ garden_pic: arr[0] })
    }
    const getPicsVal = (arr) => {
        form.setFieldsValue({ garden_pics: arr })
    }
    const getValue = (val) => {
        const { addr, longitude, latitude } = val;
        form.setFieldsValue({ garden_addr: addr, lntlat: { lnt: longitude, lat: latitude } })
    }
    return (<>
        <Card
            extra={<Button type="primary" onClick={history.goBack}>返回</Button>}
        >
            <Form
                form={form}
                labelCol={{ span: 4 }}
                labelAlign='left'
                wrapperCol={{ span: 10 }}
            >
                {
                    editInfoForm.map(item => {
                        return <Form.Item label={item.label} name={item.name} key={item.label}
                            rules={[{ required: true, message: `请输入${item.label}` }]}
                        >
                            <Input placeholder={`请输入${item.label}`}></Input>
                        </Form.Item>
                    })
                }
                <Form.Item label='小区描述' name='garden_desc' rules={[{ required: true, message: '请输入小区描述' }]}>
                    <Input.TextArea placeholder="请输入小区描述"></Input.TextArea>
                </Form.Item>
                <Form.Item label='小区形象图片' name='garden_pic' rules={[{ required: true, message: '请上传小区形象图片' }]}
                >
                    <Uploadpic getSrc={getPicVal} src={[state.garden_pic]} maxCount={1} />
                </Form.Item>
                <Form.Item label='请选择小区位置' name='lntlat' rules={[{ required: true, message: '请选择小区位置' }]}>
                    {/* <MapElement location={mapAdress} lnglat={state} /> */}
                    <Address state={state} getValue={getValue} />
                </Form.Item>
                <Form.Item label="小区位置" name="garden_addr"
                    wrapperCol={{ span: 12, offset: 1 }}
                    rules={[{ required: true, message: "请输入小区位置" }]}
                >
                    <Input placeholder='请输入小区详细位置' />
                </Form.Item>
                <div className={'form-block__title'}>小区信息（非必填）</div>
                <Form.Item label="建成年份" name="building_year">
                    <RangePicker picker="year" allowEmpty={[true, true]} />
                </Form.Item>
                <Form.Item label="物业费用" style={{ marginBottom: 0 }} >
                    <Form.Item
                        name="property_fee_start"
                        style={{ display: 'inline-block', width: "calc(40%)" }}
                        dependencies={['property_fee_end']}
                        rules={[
                            ({ getFieldValue }) => ({
                                validator(_, value) {
                                    if (getFieldValue('property_fee_end')) {
                                        if (!value) {
                                            return Promise.reject(new Error('请输入最低价'));
                                        }
                                    }
                                    return Promise.resolve();
                                },
                            }),
                        ]}
                    >
                        <InputNumber min={0} prefix="￥" style={{ width: '100%' }} placeholder="最低价" />
                    </Form.Item>
                    <Form.Item style={{ display: 'inline-block', margin: '0 8px' }}>至</Form.Item>
                    <Form.Item
                        name="property_fee_end"
                        dependencies={['property_fee_start']}
                        rules={[
                            ({ getFieldValue }) => ({
                                validator(_, value) {
                                    if (getFieldValue('property_fee_start')) {
                                        if (!value) {
                                            return Promise.reject(new Error('请输入最高价'));
                                        } else if (getFieldValue('property_fee_start') > value) {
                                            return Promise.reject(new Error('请输入合理的价格'));
                                        }
                                    }
                                    return Promise.resolve();
                                },
                            }),
                        ]}
                        style={{ display: 'inline-block', width: "calc(40%)", margin: '0 8px' }}
                    >
                        <InputNumber min={0} prefix="￥" style={{ width: '100%' }} placeholder="最高价" />
                    </Form.Item>
                </Form.Item>
                <Form.Item label="燃气费用" style={{ marginBottom: 0 }} >
                    <Form.Item
                        name="gas_fee_start"
                        style={{ display: 'inline-block', width: "calc(40%)" }}
                        dependencies={['gas_fee_end']}
                        rules={[
                            ({ getFieldValue }) => ({
                                validator(_, value) {
                                    if (getFieldValue('gas_fee_end')) {
                                        if (!value) {
                                            return Promise.reject(new Error('请输入最低价'));
                                        }
                                    }
                                    return Promise.resolve();
                                },
                            }),
                        ]}
                    >
                        <InputNumber min={0} prefix="￥" style={{ width: '100%' }} placeholder="最低价" />
                    </Form.Item>
                    <Form.Item style={{ display: 'inline-block', margin: '0 8px' }}>至</Form.Item>
                    <Form.Item
                        name="gas_fee_end"
                        dependencies={['gas_fee_start']}
                        rules={[
                            ({ getFieldValue }) => ({
                                validator(_, value) {
                                    if (getFieldValue('gas_fee_start')) {
                                        if (!value) {
                                            return Promise.reject(new Error('请输入最高价'));
                                        } else if (getFieldValue('gas_fee_start') > value) {
                                            return Promise.reject(new Error('请输入合理的价格'));
                                        }
                                    }
                                    return Promise.resolve();
                                },
                            }),
                        ]}
                        style={{ display: 'inline-block', width: "calc(40%)", margin: '0 8px' }}
                    >
                        <InputNumber min={0} prefix="￥" style={{ width: '100%' }} placeholder="最高价" />
                    </Form.Item>
                </Form.Item>
                <Form.Item label="建筑类型" name="building_type">
                    <Select placeholder='请选择建筑类型' allowClear options={buildingTypes} />
                </Form.Item>
                <Form.Item label="用水类型" name="water_type">
                    <Select placeholder='请选择用水类型' allowClear mode="tags" options={[
                        { label: "民用", value: '1' },
                        { label: "商用", value: '2' },
                    ]} />
                </Form.Item>
                <Form.Item label="用电类型" name="electric_type">
                    <Select placeholder='请选择用电类型' allowClear mode="tags" options={[
                        { label: "民用", value: '1' },
                        { label: "商用", value: '2' },
                    ]} />
                </Form.Item>
                <Form.Item label="小区均价" name="avg_price">
                    <InputNumber min={0} prefix="￥" style={{ width: '100%' }} placeholder="请输入均价" />
                </Form.Item>
                {gardenInfo.map(item => {
                    if (item.name == "area_percent" || item.name == "green_percent") {
                        return (
                            <Form.Item
                                label={item.label}
                                name={item.name}
                                key={item.name}
                            >
                                <InputNumber placeholder={`请输入${item.label}`} addonAfter="%" />
                            </Form.Item>);
                    } else if (item.name == "building_area" || item.name == "covered_area") {
                        return (
                            <Form.Item
                                label={item.label}
                                name={item.name}
                                key={item.name}
                            >
                                <InputNumber placeholder={`请输入${item.label}`} addonAfter="m²" />
                            </Form.Item>);
                    } else if (item.name == "space_total" || item.name == "house_total") {
                        return (
                            <Form.Item
                                label={item.label}
                                name={item.name}
                                key={item.name}
                            >
                                <InputNumber placeholder={`请输入${item.label}`} style={{ width: "100%" }} />
                            </Form.Item>);
                    } else if (item.name == "space_info") {
                        return (
                            <Form.Item
                                label={item.label}
                                name={item.name}
                                key={item.name}
                                extra={<span>例：1:1.12 </span>}
                            >
                                <Input placeholder={`请输入${item.label}`} style={{ width: "100%" }} />
                            </Form.Item>);
                    }
                    else {
                        return (
                            <Form.Item
                                label={item.label}
                                name={item.name}
                                key={item.name}

                            >
                                <Input placeholder={`请输入${item.label}`} style={{ width: "100%" }} />
                            </Form.Item>);
                    }
                })}
                <Form.Item label='小区图片' name='garden_pics' wrapperCol={{ span: 24 }}
                >
                    <Uploadpic getSrc={getPicsVal} src={state.garden_pics} maxCount={9} />
                </Form.Item>
                <div className='createGardenBut'>
                    <Button type='primary' onClick={editGarden}>修改</Button>
                </div>
            </Form>
        </Card>
    </>)
}
export default EditGarden