import * as React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Select, Popconfirm, message, Input, Cascader } from 'antd'
import { PlusOutlined } from '@ant-design/icons'
import { Link, withRouter } from 'react-router-dom'
import { GetProvinceCityArea } from '../../services/api'
import { GetGardenStreet } from '../../services/garden'
import { Garden, GanderEntry, Company_login, GardenCheck, Garden_mch, PayMode } from '../../services/garden'

const GardenList = (props: any) => {
  const { not_approved } = props
  // @ts-ignore
  const columns: any = [
    {
      title: '小区名称',
      align: "center",
      dataIndex: 'garden_name',
      ellipsis: true,
    },
    {
      title: '商户号',
      align: "center",
      search: false,
      dataIndex: 'mch_id',
      ellipsis: true,
    },
    {
      title: '支付类型',
      align: "center",
      search: false,
      dataIndex: 'pay_mode',
      valueEnum: {
        0: "暂未设置",
        1: "仅线下支付",
        2: "线上支付到物业公司账户",
        3: "线上支付到软件公司账户"
      },
      ellipsis: true,
    },
    {
      title: '城市',
      align: "center",
      dataIndex: 'city',
      search: false
    },
    {
      title: '街道社区',
      align: "center",
      dataIndex: 'committee',
      search: false,
      ellipsis: true,
    },
    {
      title: '小区详细地址',
      align: "center",
      dataIndex: 'garden_addr',
      search: false,
      ellipsis: true,
    },
    {
      title: '物业联系人',
      align: "center",
      dataIndex: 'property_person',
      search: false,
    },
    {
      title: '物业联系电话',
      align: "center",
      dataIndex: 'property_phone',
      search: false,
      ellipsis: true,
    },
    {
      title: '管理入口',
      dataIndex: 'company_phone',
      search: false,
      align: 'center',
      render: (_, record) => <Button type='link' style={{ padding: '0' }} onClick={() => manageLogin(record.id)}>管理入口</Button>
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      width: "200px",
      align: 'center',
      render: (_, row, index, action) => <>
        <Link to={{ pathname: '/admin/garden/edit', state: row }} ><Button type='link'>修改</Button></Link>
        <Popconfirm
          title="确认删除该小区"
          onConfirm={() => deleteGarden(row.id)}
        >
          <Button type='link'>删除</Button>
        </Popconfirm>
        {/* <Button type='link' onClick={() => {
          setState(pre => ({ ...pre, keyinfoVisible: true, garden_id: row.garden_id }))
        }}>关键信息修改</Button> */}
        <Button type='link' onClick={() => {
          setState(pre => ({ ...pre, visible: true, garden_id: row.garden_id }));
          form.setFieldsValue({ mch_id: row.mch_id })
        }}>设置小区支付商户号</Button>
        <Button type='link' onClick={() => {
          setState(pre => ({ ...pre, paymodeVisible: true, garden_id: row.garden_id }));
          if (row.pay_mode !== 0) {
            pay_modeform.setFieldsValue({ pay_mode: row.pay_mode })
          }
        }}>设置小区线上支付类型</Button>
      </>
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    paymodeVisible: false,
    garden_id: null,
    keyinfoVisible: false
  })
  const actionRef = React.useRef<ActionType>();
  const [form] = Form.useForm();
  const [pay_modeform] = Form.useForm();
  const [keyinfoForm] = Form.useForm();
  const [options, setOptions] = React.useState([]);
  const deleteGarden = async (id) => {
    await Garden({ method: 'delete', id })
    message.success('删除成功')
    actionRef.current?.reload()
  }

  const manageLogin = async (id) => {
    const { data } = await GanderEntry({ garden_id: id })
    sessionStorage.setItem('area-garden-token', data.token)
    Company_login({ token: data.token }).then(res => {
      const { token, user, uid, permissions, company } = res.data;
      let win = window.open('http://47.108.135.38:30002/admin/index')
      // let win = window.open('http://localhost:3000/admin/index')
      window.addEventListener('message', (e) => {
        win?.postMessage({ token, user, uid, permissions, company }, '*')
      })
    })
  }
  const addGarden = () => {
    GardenCheck().then(res => {
      if (res.data.can_add == true) {
        props.history.push('/admin/garden/create')
      } else {
        message.error("小区数量用尽，暂时无法添加")
      }
    })
  }
  const onSubmit = () => {
    form.validateFields().then(async (values) => {
      const { garden_id } = state;
      const res = await Garden_mch({
        method: "put",
        garden_id,
        ...values
      })
      message.success("修改成功");
      actionRef.current?.reload();
      setState(pre => ({ ...pre, visible: false }));
    })
  }
  const payModeSubmit = () => {
    pay_modeform.validateFields().then(async (values) => {
      const { garden_id } = state;
      const res = await PayMode({
        garden_id,
        ...values,
      })
      message.success("修改成功");
      actionRef.current?.reload();
      setState(pre => ({ ...pre, paymodeVisible: false }));
    })
  }
  const keyinfoSubmit = () => {
    console.log(state.garden_id);

  }
  const paymodeArr = [
    { label: "仅支持线下支付", value: 1 },
    { label: "线上支付到物业公司账户", value: 2 },
    { label: "线上支付到软件公司账户", value: 3 },
  ]
  const onChange = (value) => {
    console.log(value);
  };

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey={row => row.id}
        options={false}
        request={async (
        ) => {
          const { data: data1 }: any = await Garden({ not_approved });
          const { data: data2 }: any = await Garden_mch({});
          let data = new Array;
          data1.map(item => {
            data2.map(key => {
              if (item.id == key.garden_id) {
                let result = { ...item, ...key };
                data.push(result)
              }
            })
          })
          let result = data.map(item => {
            if (item.pay_mode == 0) {
              return { ...item, pay_mode: "暂未设置" }
            } else if (item.pay_mode == 1) {
              return { ...item, pay_mode: "仅线下支付" }
            } else if (item.pay_mode == 2) {
              return { ...item, pay_mode: "线上支付到物业公司账户" }
            } else if (item.pay_mode == 3) {
              return { ...item, pay_mode: "线上支付到软件公司账户" }
            }
          })
          return {
            data: result,
            success: true,
            // 不传会使用 data 的长度，如果是分页一定要传
            total: data1.total,
          };
        }}
        columns={columns}
        params={{ not_approved }}
        toolBarRender={() => [
          <Button type='primary' onClick={addGarden}>  <PlusOutlined />添加</Button>
        ]}
      />
      <Modal
        title='修改支付商户号'
        visible={state.visible}
        width={480}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form form={form}>
          <Form.Item label="支付商户号" name="mch_id"
            rules={[{ required: true, message: "请输入支付商户号" }]}>
            <Input placeholder='请输入支付商户号' />
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        title='修改线上支付类型'
        visible={state.paymodeVisible}
        width={480}
        onOk={payModeSubmit}
        onCancel={() => setState(pre => ({ ...pre, paymodeVisible: false }))}
      >
        <Form form={pay_modeform}>
          <Form.Item label="线上支付类型" name="pay_mode"
            rules={[{ required: true, message: "请选择支付类型" }]}>
            <Select placeholder='请选择支付类型' options={paymodeArr} />
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        title="小区关键信息修改"
        visible={state.keyinfoVisible}
        onCancel={() => setState(pre => ({ ...pre, keyinfoVisible: false }))}
        onOk={keyinfoSubmit}
      >
        <Form
          form={keyinfoForm}
        >
          <Form.Item label="城市">
            <Cascader options={options} onChange={onChange} placeholder="请选择城市" />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(GardenList)