import React, { useEffect } from "react";
import { Card, Row, Col } from "antd";
import "./home.scss";
import { Statistic } from "../../services/account";
import * as echarts from 'echarts';
import moment from 'moment'


const Home = () => {
    const [totalData, setTotalData]: any = React.useState({});
    const [totalItems, setTotalItems] = React.useState({
        garden_count: {
            title: "小区数量",
            describe: "当前物业公司下小区总数",
            color: "#03BB7A"
        },
        house_count: {
            title: "房屋数量",
            describe: "当前物业公司下房屋总数",
            color: "rgb(195, 84, 84)"
        },
        user_count: {
            title: "住户人数",
            describe: "当前物业公司下已住住户人数",
            color: "#179516"
        },
        space_count: {
            title: "车位数量",
            describe: "当前物业公司下车位总数",
            color: "rgb(248, 140, 46)"
        }
    });
    useEffect(() => {
        getData();
    }, [])
    const getData = async () => {
        const { data } = await Statistic();
        setTotalData(data);
        canvasLine(data);
    }
    type EChartsOption = echarts.EChartsOption
    const canvasLine = (data) => {
        var chartDom = document.getElementById('main')!;
        var myChart = echarts.init(chartDom);
        var option: EChartsOption;
        option = {
            title: {
                text: ''
            },
            tooltip: {
                trigger: 'axis'
            },
            legend: {},
            toolbox: {
                show: false,
                feature: {
                    dataZoom: {
                        yAxisIndex: 'none'
                    },
                    dataView: { readOnly: false },
                    magicType: { type: ['line', 'bar'] },
                    restore: {},
                    saveAsImage: {}
                }
            },
            xAxis: {
                type: 'category',
                boundaryGap: false,
                data: data.deal_list.map(item => {
                    return moment(item.date_timestamp * 1000).format('DD') + '号'
                })
            },
            yAxis: {
                type: 'value',
                axisLabel: {
                    formatter: '{value}'
                }
            },
            series: [
                {
                    name: '成交量',
                    type: 'line',
                    color: "rgb(195, 84, 84)",
                    data: data.deal_list.map(item => {
                        return item.deal_count
                    }),
                },
                {
                    name: '成交额',
                    type: 'line',
                    color:"#03BB7A",
                    data: data.deal_list.map(item => {
                        return item.deal_amount
                    }),
                }
            ]
        };
        option && myChart.setOption(option);
    }

    return (<>
        <Card>
            <Row justify="space-between" className="pl-10 pr-10">
                <div className={'form-block__title'}>数据统计
                </div>
                {Object.keys(totalItems).map((key) => (
                    <Col span={5} key={totalItems[key]?.title}>
                        <div
                            className="total-block"
                            style={{ backgroundColor: totalItems[key]?.color }}
                        >
                            <div className="total-title">{totalItems[key]?.title}</div>
                            <div className="total-count">
                                {totalData[key]}
                            </div>
                            {totalItems[key]?.describe}
                        </div>
                    </Col>
                ))}
            </Row>
            <div className={'form-block__title'}>近7日收入
            </div>
            <div style={{ height: 440 }} id="main" />
        </Card>
    </>)
}

export default Home