import { Button, Modal, Form, InputNumber, message } from "antd";
import React, { useState } from "react";
import type { ActionType } from "@ant-design/pro-table";
import ProTable from "@ant-design/pro-table";
import { BuyPackageList, Order_renew } from "../../services/buypackage";
import moment from "moment";

const BuyPackage = () => {
    const columns: any = [
        {
            title: "物业公司",
            align: "center",
            search: false,
            dataIndex: "company_name"
        },
        {
            title: "套餐名",
            align: "center",
            search: false,
            dataIndex: "name"
        },
        {
            title: "小区个数",
            align: "center",
            search: false,
            dataIndex: ""
        },
        {
            title: "周期（年）",
            align: "center",
            search: false,
            dataIndex: "period"
        },
        {
            title: "购买时间",
            align: "center",
            search: false,
            dataIndex: ""
        },
        {
            title: "价格（元/年）",
            align: "center",
            search: false,
            render: (_, row) => (row.price / 100).toFixed(2)
        },
        {
            title: "订单金额",
            align: "center",
            search: false,
            render: (_, row) => (row.amount / 100).toFixed(2)
        },
        {
            title: "套餐到期时间",
            align: "center",
            search: false,
            dataIndex: "expire_at",
            render: (_, row) => <>{row.expire_at !== 0 ?
                moment(row.expire_at * 1000).format("YYYY-MM-DD")
                : '-'}</>
        },
        {
            title: "状态",
            align: "center",
            dataIndex: "status",
            valueEnum: {
                1: { text: "待认证", status: "Default" },
                2: { text: "已通过", status: "Success" },
                3: { text: "未通过", status: "Error" }
            }
        },
        {
            title: "操作",
            align: "center",
            search: false,
            dataIndex: "option",
            render: (_, row) => <>
                {row.status == 2 ? <Button type="link" onClick={() => {
                    console.log(row);

                    setState(pre => ({ ...pre, visible: true }));
                    setrenewInfo(row)
                }} >续费</Button> : <Button type="link" disabled>续费</Button>}
            </>
        },
    ]
    const actionRef = React.useRef<ActionType>() as any;
    const [form] = Form.useForm();
    const [renewInfo, setrenewInfo]: any = useState({})
    const [state, setState] = useState({
        visible: false
    })
    const periodHandle = (type) => {
        let value = form.getFieldValue('period')
        if (type == 'add') {
            form.setFieldsValue({ 'period': value + 1 })
        } else {
            if (value !== 1) {
                form.setFieldsValue({ 'period': value - 1 })
            }
        }
    }
    const onSubmit = () => {
        form.validateFields().then(async (values) => {
            const { period } = values;
            const { garden_id, package_id, price } = renewInfo;
            const amount = period * price;
            if (garden_id == 0) {
                message.info("请先绑定小区")
            } else {
                await Order_renew({
                    period,
                    garden_id,
                    package_id,
                    amount
                })
                message.success('操作成功')
                setState(pre => ({ ...pre, visible: false }))
                actionRef.current?.reload()
            }
        })
    }
    return (<>
        <ProTable
            actionRef={actionRef}
            rowKey={row => row.order_id}
            request={BuyPackageList}
            options={false}
            columns={columns}
        />
        <Modal
            title='续费'
            visible={state.visible}
            width={480}
            onOk={onSubmit}
            onCancel={() => setState(pre => ({ ...pre, visible: false }))}
        >
            <Form form={form} labelCol={{ span: 4 }} wrapperCol={{ span: 10 }}
                initialValues={{ period: 1 }}
            >
                <Form.Item label="套餐">
                    <span>{renewInfo.name}</span>
                </Form.Item>
                <Form.Item name="period" label="周期" rules={[{ required: true, message: "请输入周期" }]}>
                    <InputNumber addonBefore={<div onClick={() => periodHandle('sub')}>-</div>}
                        addonAfter={<div onClick={() => periodHandle('add')}>+</div>} controls={false} min={1} />
                </Form.Item>
            </Form>
        </Modal>
    </>)
}

export default BuyPackage