import { Button, Card, Form, InputNumber, Select, Steps } from "antd";
import React, { useState } from "react";
import { useHistory } from "react-router";
import "./package.scss"
import { AddPackage } from "../../services/package";
const { Step } = Steps;

const Order = () => {
    const history = useHistory();
    const location = history.location;
    const state: any = location.state;
    const [current, setCurrent] = useState(0);
    const [num, setNum] = useState(1);
    const [result, setResult] = useState({});
    const [form] = Form.useForm();
    const next = () => {
        setCurrent(current + 1);
    };
    const firstNode = <>
        <Form form={form} labelCol={{ span: 8 }} wrapperCol={{ span: 8 }}
            initialValues={{ way: 1, period: 1 }}
        >
            <Form.Item label="套餐名">
                <span>{state.name}</span>
            </Form.Item>
            <Form.Item label="周期" name="period" rules={[{ required: true, message: "请输入周期" }]} >
                <InputNumber min={1} addonAfter="年" onChange={(e) => {
                    setNum(e)
                }} />
            </Form.Item>
            <Form.Item label="订单金额">
                <span>￥{(state.price / 100 * num).toFixed(2)}</span>
            </Form.Item>
            <Form.Item label="支付方式" name="way" >
                <Select options={[{ label: "对公转账", value: 1 }]} />
            </Form.Item>
        </Form>
    </>
    const finishedInfo = [
        { label: "订单号", name: "order_id" },
        { label: "套餐名", name: "package_name" },
        { label: "周期", name: "period" },
        { label: "小区个数", name: "garden_count" },
        { label: "订单金额", name: "amount" },
        { label: "支付方式", name: "pay_type" },
        { label: "户名", name: "bank_user_name" },
        { label: "开户行", name: "bank_name" },
        { label: "账号", name: "bank_account" },
    ]
    const finishedNode = <>
        <Form labelCol={{ span: 8, }} wrapperCol={{ span: 8, offset: 1 }}>
            {finishedInfo.map(item => {
                return <Form.Item label={item.label} key={item.name}>
                    <span>{result[item.name]}</span>
                </Form.Item>
            })}
            <Form.Item label="备注">
                <span className="tips_span">汇款时将汇款识别码填写至汇款单“用途”，“附言”等栏，超出1个工作日未对账，请提供订单号及正规的汇款底单(汇款底单需包含收付款户名，收付款账号，公章等，如存在代汇款、汇款后委托他人或企业用款等情况，还需提供对应的代付/委托声明，如客户为个人汇款，还需额外提供与汇款人一致的身份证正反面)邮件至x0oax@autocareai.com，我司会在一个工作日内受理。
                </span>
            </Form.Item>
        </Form>
    </>
    const steps = [
        {
            title: '下单',
            content: firstNode,
        },
        {
            title: '审核',
            content: finishedNode,
        }
    ];
    const addPackage = () => {
        form.validateFields().then(async (values) => {
            const { period } = values;
            const { data } = await AddPackage({ package_id: state.id, period, amount: period * state.price })
            setResult(data);
            next()
        })
    }
    return (<>
        <Card extra={<Button type="primary" onClick={history.goBack}>返回</Button>}>
            <Steps current={current}>
                {steps.map(item => (
                    <Step key={item.title} title={item.title} />
                ))}
            </Steps>
            <div className="steps-content">{steps[current].content}</div>
            <div className="steps-action">
                {current < steps.length - 1 && (
                    <Button type="primary" onClick={addPackage}>
                        确认
                    </Button>
                )}
            </div>
        </Card>
    </>)
}

export default Order