import React, { FC, useEffect, useState } from 'react'
import { Form, Card, Image, Modal, Input, Upload, Button, message, Select } from 'antd'
import { Company } from '../../services/company'
import { UploadOutlined } from '@ant-design/icons'
import { useForm } from 'antd/lib/form/Form'
import Uploadpic from '../../utils/upload'
import './index.scss'

const CompanyInfo: FC = () => {
  const [dataList, setDataList]: any = useState({})
  const [form] = useForm()
  const companyInfo = [
    {
      label: "企业名称",
      name: "company_name"
    },
    {
      label: "企业电话",
      name: "company_phone"
    },
    {
      label: "企业地址",
      name: "company_addr"
    },
    {
      label: "企业网址",
      name: "site"
    },
    {
      label: "社会信用码",
      name: "social_code"
    },
    {
      label: "营业执照类型",
      name: "license_type"
    }
  ]
  const [previewVisible, setPreviewVisible] = useState(false);
  const [previewImage, setPreviewImage] = useState();
  const [previewTitle, setPreviewTitle] = useState('');
  const handleCancel = () => setPreviewVisible(false);
  const getCompany = async () => {
    const { data } = await Company({})
    console.log(data);

    form.setFieldsValue(data)
    setDataList(data)
  }
  useEffect(() => {
    getCompany()
  }, [])
  const updateCompany = () => {
    form.validateFields().then(async (value) => {
      console.log(value);
      let business_license = value.business_license
      let logo = value.logo
      if (value.business_license.file) {
        business_license = value.business_license.fileList[0].response.data
      }
      if (value.logo.file) {
        logo = value.logo.fileList[0].response.data
      }
      await Company({
        method: 'put',
        ...value,
        business_license,
        logo
      })
      message.success('更新成功')
      // window.location.href =('/admin/setting/info')
    })
  }
  const getBusPic = (val) =>{
    form.setFieldsValue({business_license:val[0]})
  };
  const getLogoPic = (val) =>{
    form.setFieldsValue({logo:val[0]})
  };
  return (
    <><Card>
      <Form
        labelCol={{ span: 3 }}
        labelAlign='left'
        wrapperCol={{ span: 7 }}
        form={form}

      >
        {companyInfo.map(item => {
          if (item.name == 'license_type') {
            return <Form.Item label={item.label} name={item.name} key={item.label}
              rules={[{ required: true, message: `请输入${item.label}` }]}>
              <Select placeholder='多证合一营业执照'>
                <Select.Option value={1}>多证合一营业执照</Select.Option>
                <Select.Option value={2}>普通营业执照</Select.Option>
              </Select>
            </Form.Item>
          } else {
            return (<Form.Item label={item.label} name={item.name} key={item.label}
              rules={[{ required: true, message: `请输入${item.label}` }]}
            >
              <Input></Input>
            </Form.Item>)
          }
        })}
        <Form.Item label='营业执照' name='business_license' rules={[{ required: true, message: '请上传营业执照' }]}
        >
          <Uploadpic getSrc={getBusPic} src={[dataList.business_license]} maxCount={1} />
        </Form.Item>
        <Form.Item label='LOGO' name='logo' rules={[{ required: true, message: '请上传小区LOGO' }]}
        >
          <Uploadpic getSrc={getLogoPic} src={[dataList.logo]} maxCount={1} />
        </Form.Item>
        <Form.Item label='企业简介' name='desc' rules={[{ required: true, message: `请输入企业简介` }]}>
          <Input.TextArea>
          </Input.TextArea>
        </Form.Item>
        <div className='updateButton'>
          <Button type='primary' onClick={updateCompany}>更新</Button>
        </div>
      </Form>
    </Card><Modal visible={previewVisible} title={previewTitle} footer={null} onCancel={handleCancel}>
        <img
          alt="example"
          style={{
            width: '100%',
          }}
          src={previewImage} />
      </Modal></>
  )
}

export default CompanyInfo