import React, { useState, FC } from "react";
import { Button, Form, Input, message } from "antd";
import { ProFormCaptcha } from '@ant-design/pro-form';
import { LockOutlined } from '@ant-design/icons';
import { Getcaptcha, Reset_password } from "../../services/user";
import './index.scss'
const FindPassword: FC = (props) => {
    const [form] = Form.useForm()
    const [code, setVcode]: any = useState({
        vcode: null
    })
    const [checkCaptcha, setCheckCaptcha] = useState('showDisplay')
    const [checkPassword, setCheckPassword] = useState('hiddenDisplay')
    const nextStep = () => {
        form.validateFields(['phone', 'vcode']).then(async (value) => {
            let { vcode } = code
            if (vcode === value.vcode - 0) {
                setCheckCaptcha('hiddenDisplay')
                setCheckPassword('showDisplay')
            } else {
                message.error('请输入正确的验证码')
            }
        })
    }
    const onFinished = () => {
        form.validateFields().then(async (value) => {
            const { phone, vcode, password } = value;
            console.log(phone, vcode, password);
            await Reset_password({ phone, vcode: vcode - 0, password })
            message.success('修改成功')
            window.location.href = '/company/register'
        })
    }
    const goLogin = () => {
        window.location.href = '/login'
    }
    return (<>
        <div className="login-header">
            <div><span className="findTitle">物业管理系统</span></div>
            <div><span className="goBack" onClick={goLogin}>登录</span></div>
        </div>
        <main className="container">
            <div className="container-title">
                <div className="container-title__split"></div>
                <div className="container-title__content">找回密码</div>
            </div>
            <div className="container-inner">
                <Form
                    className={checkCaptcha}
                    form={form}
                    validateTrigger='onBlur'
                >
                    <Form.Item name='phone' rules={[
                        {
                            required: true,
                            message: '请输入手机号！',
                        },
                        {
                            pattern: /^1\d{10}$/,
                            message: '手机号格式错误！',
                        },
                    ]}>
                        <Input placeholder="请输入手机号"
                            // autoComplete='off'
                            className="container-inner-input"></Input>
                    </Form.Item>
                    <ProFormCaptcha
                        fieldProps={{
                            size: 'large',
                            prefix: <LockOutlined className={'prefixIcon'} />,
                        }}
                        captchaProps={{
                            size: 'large',
                        }}
                        placeholder={'请输入验证码'}
                        captchaTextRender={(timing, count) => {
                            if (timing) {
                                return `${count} ${'获取验证码'}`;
                            }
                            return '获取验证码';
                        }}
                        name="vcode"
                        rules={[
                            {
                                required: true,
                                message: '请输入验证码！',
                            },
                        ]}
                        onGetCaptcha={async () => {
                            await form.validateFields(['phone']).then(async (value) => {
                                console.log(value);
                                const { phone } = value
                                const { data } = await Getcaptcha({ phone })
                                setVcode(data)
                                message.success('验证码发送成功')
                            })
                        }}
                    />
                    <Form.Item className="login-div">
                        <Button type="primary" className="login-button" onClick={nextStep}>下一步</Button>
                    </Form.Item>
                </Form>
                <div className={checkPassword}>
                    <div className="setPassword">设置新密码</div>
                    <Form form={form} validateTrigger='onBlur'>
                        <Form.Item name='password'
                            rules={[
                                { required: true, message: '请输入新密码' },
                                { pattern: /^[a-zA-Z]\w{5,17}$/, message: '密码格式错误' }
                            ]}
                            hasFeedback
                        >
                            <Input.Password placeholder="请输入新密码" className="container-inner-input"
                                visibilityToggle={false}
                            ></Input.Password>
                        </Form.Item>
                        <Form.Item name='confirm'
                            dependencies={['password']}
                            hasFeedback
                            rules={[
                                {
                                    required: true,
                                    message: '请再次输入新密码!',
                                },
                                ({ getFieldValue }) => ({
                                    validator(_, value) {
                                        if (!value || getFieldValue('password') === value) {
                                            return Promise.resolve();
                                        }
                                        return Promise.reject(new Error('两次密码输入不一致，请重新输入'));
                                    },
                                }),
                            ]}
                        >
                            <Input.Password placeholder="请再次输入新密码" className="container-inner-input"
                                visibilityToggle={false}
                            ></Input.Password>
                        </Form.Item>
                        <div className="tips">
                            <span className="warning">密码由8-16位数字、字母或符号组成</span>
                            <span className="warning">至少含两种字符以上</span>
                        </div>
                        <Form.Item className="login-div">
                            <Button type="primary" className="login-button" onClick={onFinished}>确定</Button>
                        </Form.Item>
                    </Form>
                </div>
            </div>
        </main>
    </>)
}
export default FindPassword