import sha256 from 'sha256'
import * as React from 'react'
import './index.scss'
import './login.scss'
import { PostLogin } from '../../services/api'
import { Getcaptcha,Login_by_phone } from '../../services/user'
import { LoginForm, ProFormText, ProFormCaptcha } from '@ant-design/pro-form';
import {
  UserOutlined,
  MobileOutlined,
  LockOutlined,
} from '@ant-design/icons';
import { message, Tabs ,Form} from 'antd';
import { useState } from 'react';

type LoginType = 'phone' | 'account';

const Login: React.FC = (props: any) => {
  const [visible, setVisible] = useState(false)
  const [loginAccount,setloginAccount] =useState([])
  const onFinish = async (values: any) => {

    if (loginType == 'account') {
      const name = values.username
      const password = values.password || 'zaq123edc'
      const { data } = await PostLogin({ user: name, password: sha256(password) })
      message.success('登录成功！')
      sessionStorage.setItem('area-token', data.token)
      sessionStorage.setItem('username', name)
      window.location.href = '/admin/home'
    }
    if (loginType == 'phone') {
      const phone = values.mobile
      const vcode = values.captcha - 0
      const { data } :any= await Login_by_phone({ phone, vcode })
      if (data.length > 1) {
        setloginAccount(data.list)
        setVisible(true)
        console.log(1);
        //暂定
      } else {
        message.success('登录成功！')
        sessionStorage.setItem('area-token', data.token)
        sessionStorage.setItem('username', data.user)
        window.location.href = '/admin/garden'
      }
    }
  };
  const [loginType, setLoginType] = useState<LoginType>('account');
  const [form] = Form.useForm()
  return (
    <div className="login-container">
      <div className="login-box">
        <div className="login-cover">
          <div className="login-title">
            勤爱家
            <div>物业管理系统</div>
          </div>
        </div>
        <div className="login-form">
          <div style={{ backgroundColor: 'white' }}>
            <LoginForm
              onFinish={onFinish}
              form={form}
              validateTrigger='onBlur'
            >
              <Tabs activeKey={loginType} onChange={(activeKey) => setLoginType(activeKey as LoginType)}>
                <Tabs.TabPane key={'account'} tab={'账号密码登录'} />
                <Tabs.TabPane key={'phone'} tab={'手机号登录'} />
              </Tabs>
              {loginType === 'account' && (
                <>
                  <ProFormText
                    name="username"
                    fieldProps={{
                      size: 'large',
                      prefix: <UserOutlined className={'prefixIcon'} />,
                    }}
                    placeholder={'手机/账号'}
                    rules={[
                      {
                        required: true,
                        message: '请输入用户名!',
                      },
                    ]}
                  />
                  <ProFormText.Password
                    name="password"
                    fieldProps={{
                      size: 'large',
                      prefix: <LockOutlined className={'prefixIcon'} />,
                    }}
                    placeholder={'密码'}
                    rules={[
                      {
                        required: true,
                        message: '请输入密码！',
                      },
                    ]}
                  />
                </>
              )}
              {loginType === 'phone' && (
                <>
                  <ProFormText
                    fieldProps={{
                      size: 'large',
                      prefix: <MobileOutlined className={'prefixIcon'} />,
                    }}
                    name="mobile"
                    placeholder={'手机号'}
                    rules={[
                      {
                        required: true,
                        message: '请输入手机号！',
                      },
                      {
                        pattern: /^1\d{10}$/,
                        message: '手机号格式错误！',
                      },
                    ]}
                  />
                  <ProFormCaptcha
                    fieldProps={{
                      size: 'large',
                      prefix: <LockOutlined className={'prefixIcon'} />,
                    }}
                    captchaProps={{
                      size: 'small',
                    }}
                    placeholder={'请输入验证码'}
                    captchaTextRender={(timing, count) => {
                      if (timing) {
                        return `${count} ${'获取验证码'}`;
                      }
                      return '获取验证码';
                    }}
                    name="captcha"
                    phoneName="mobile"
                    rules={[
                      {
                        required: true,
                        message: '请输入验证码！',
                      },
                    ]}
                    onGetCaptcha={async (phone) => {
                      await Getcaptcha({phone})
                      message.success('验证码发送成功')
                    }}
                  />
                </>
              )}
              <div
                style={{
                  marginBottom: 24,
                }}
              >
                
                <a
                  style={{
                    float: 'right',
                    marginBottom:"15px"
                  }}
                  onClick={()=>{
                    window.location.href =('/find/password')   
                  }}
                >
                  忘记密码
                </a>
              </div>
            </LoginForm>
            <div
                style={{
                  marginBottom: 24,
                }}
              >
                
                <a
                  style={{
                    float: 'right',
                    marginBottom:"15px",
                    marginTop:"15px"
                  }}
                  onClick={()=>{
                    window.location.href = '/company/register'
                  }}
                >
                  企业注册
                </a>
              </div>
          </div>
        </div>
      </div>
    </div>
  )
}

export default Login
